Administrators guide
====================

.. toctree::

    quick
    install
    deployments
    upgrade
    auth
    access
    projects
    languages
    continuous
    licensing
    translating
    checks
    machine
    addons
    memory
    config
    sample
    management
    whiteboard
    componentlists
    optionals
